package com.pj.utils;

import java.util.function.Supplier;

import cn.dev33.satoken.fun.SaFunction;

/**
 * 代码语法糖封装 
 * 
 * @author kong
 * @since 2022-11-21
 */
public class Sugar {

	/**
	 * 执行一个 Lambda 表达式，返回这个 Lambda 表达式的结果值，
	 * <br> 方便组织代码，例如: 
	 * <pre> 
	 	int value = Sugar.get(() -> {
			int a = 1;
			int b = 2;
			return a + b;
		});
		</pre> 
	 * @param <R> 返回值类型 
	 * @param lambda lambda 表达式
	 * @return lambda 的执行结果
	 */
	public static <R> R get(Supplier<R> lambda) {
		return lambda.get();
	}

	/**
	 * 执行一个 Lambda 表达式 
	 * <br> 方便组织代码，例如: 
	 * <pre> 
	 	int value = Sugar.get(() -> {
			int a = 1;
			int b = 2;
			return a + b;
		});
		</pre> 
	 * @param lambda lambda 表达式
	 */
	public static void exe(SaFunction lambda) {
		lambda.run();
	}

//	/**
//	 * 执行一个 Lambda 表达式，返回这个 Lambda 表达式的结果值，
//	 * <br> 方便组织代码，例如: 
//	 * <pre> 
//	 	int value = Sugar.get(r -> {
//			int a = 1;
//			int b = 2;
//			return a + b;
//		});
//		</pre> 
//	 * @param <T> 参数类型
//	 * @param <R> 返回值类型 
//	 * @param lambda lambda 表达式
//	 * @return lambda 的执行结果
//	 */
//	public static <T, R> R get(Function<T, R> lambda) {
//		return lambda.apply(null);
//	}

}
